Struct debug_interface::NodeDebugClient[][src]

pub struct NodeDebugClient { /* fields omitted */ }
Implement default utility client for NodeDebugInterface

Implementations

Create NodeDebugInterfaceClient from a valid socket address.

Retrieves the individual node metric. Requires all sub fields to match in alphabetical order.

Retrieves all node metrics for a given metric name. Allows for filtering metrics by fields afterwards.