pub struct NodeDebugClient { /* fields omitted */ }
Implement default utility client for NodeDebugInterface
Create NodeDebugInterfaceClient from a valid socket address.
Retrieves the individual node metric. Requires all sub fields to match in alphabetical order.
Retrieves all node metrics for a given metric name. Allows for filtering metrics by fields afterwards.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,